@@ -1,14 +1,17 @@
-from params import Param, QueryParam, PathParam
+from resttouch.methods import GET
+from params import Param, QueryParam, PathParam, BodyParam
 from request import Request
 from utils import RestTouchException, iteritems
 from urlparse import urljoin
 
+
 __all__ = ('Route')
 
 
 class BaseRoute(object):
     service = None
     params = []
+    url, method = None, None
 
     def _validate_param(self, param):
         if not self.params.has_key(param[0]):
@@ -40,12 +43,17 @@ class BaseRoute(object):
     def _regroup_params(self, params):
         param_groups = {
             'query': (QueryParam, {}),
-            'path': (PathParam, {})
+            'path': (PathParam, {}),
+            'body': (BodyParam, {})
         }
         for name, param in params.iteritems():
             for group_name, data in param_groups.iteritems():
                 if isinstance(self.params[name], data[0]):
-                    data[1][name] = param
+                    if isinstance(self.params[name], BodyParam):
+                        if self.method.upper() == GET:
+                            raise RestTouchException('You can use BodyContent only in POST, PUT and DELETE methods')
+                    data[1][name] = self.params[name].__str__(param)
+
         return dict((group_name, data[1]) for group_name, data in param_groups.iteritems())
 
     def _prepare_and_regroup(self, kwargs):
@@ -53,7 +61,7 @@ class BaseRoute(object):
 
 
 class Route(BaseRoute):    
-    def __init__(self, method, url, *args, **kwargs):
+    def __init__(self, method, url, *args):
         self.method = method
         self.url = url
         self.params = dict((param.value, param) for param in args if isinstance(param, Param))
@@ -64,14 +72,13 @@ class Route(BaseRoute):
         
         groups['query'].update(extra_query)
         
-        request = Request(urljoin(
-            self.service.end_point,
-            self.url % groups['path']),
-            groups['query'],
+        request = Request(
+            urljoin(self.service.end_point, self.url % groups['path']),
+            groups['query'], groups['body'],
             self.service.headers
         )
         response = request.__getattribute__(self.method.lower())()
         
         if self.service.serializator:
-            return self.service.serializator.serialize(response)
+            return self.service.serializator.deserialize(response)
         return response
\ No newline at end of file
